@@ -142,9 +142,21 @@ class RattailConfig(object):
             else:
                 self._session_factory = lambda: (Session(), True)
 
-    def read_file(self, path, recurse=True):
+    def read_file(self, path, recurse=True, require=False):
         """
         Read in config from the given file.
+
+        By default this will "crawl" the file and recursively read in
+        any other config files which this one "includes" (or
+        "requires").
+
+        :param path: Path to the config file to read.
+
+        :param recurse: Whether the file should be recursively
+           "crawled" as described above.
+
+        :param require: If true, and the given file path is not
+           readable, will raise an error.
         """
         path = os.path.abspath(path)
         if path in self.files_requested:
@@ -163,11 +175,21 @@ class RattailConfig(object):
         ))
         if not parser.read(path):
             log.debug("ConfigParser.read() failed")
+            if require:
+                raise RuntimeError("Cannot read from config file path: {}".format(path))
             return
 
         # If recursing, walk the complete config file inheritance chain.
         if recurse:
             if parser.has_section('rattail.config'):
+
+                # first bring in any "required" files
+                if parser.has_option('rattail.config', 'require'):
+                    includes = parse_list(parser.get('rattail.config', 'require'))
+                    for included in includes:
+                        self.read_file(included, recurse=True, require=True)
+
+                # next try to bring in any "included" files
                 if parser.has_option('rattail.config', 'include'):
                     includes = parse_list(parser.get('rattail.config', 'include'))
                     for included in includes:
@@ -192,7 +214,9 @@ class RattailConfig(object):
             return
 
         # Coerce all logged timestamps to the local timezone, if possible.
-        logging.Formatter.converter = TimeConverter(self)
+        timezone = self.get('rattail', 'timezone.default', usedb=False)
+        if timezone:
+            logging.Formatter.converter = TimeConverter(self)
 
         # Flush all current config to a single file, for input to fileConfig().
         path = temp_path(suffix='.conf')
@@ -208,6 +232,12 @@ class RattailConfig(object):
         finally:
             os.remove(path)
 
+        # if we could not coerce timestamps, log a warning about that
+        if not timezone:
+            log.warning("timezone is not set, so logging timestamps may "
+                        "appear \"off\" - to fix, set a config value for "
+                        "[rattail] timezone.default")
+
     def setdefault(self, section, option, value):
         """
         Establishes a new default for the given setting, if none exists yet.
