@@ -56,6 +56,10 @@ class PhoneNumber(Base):
     def __str__(self):
         return self.number or ""
 
+    @property
+    def preferred(self):
+        return self.preference == 1
+
 
 @six.python_2_unicode_compatible
 class EmailAddress(Base):
@@ -85,6 +89,10 @@ class EmailAddress(Base):
     def __str__(self):
         return self.address or ""
 
+    @property
+    def preferred(self):
+        return self.preference == 1
+
 
 @six.python_2_unicode_compatible
 class MailingAddress(Base):
@@ -137,6 +145,10 @@ class MailingAddress(Base):
 
         return text
 
+    @property
+    def preferred(self):
+        return self.preference == 1
+
 
 class ContactMixin(object):
     """
