@@ -981,6 +981,74 @@ class ProductVolatile(Base):
     """)
 
 
+class PendingProduct(Base):
+    """
+    A "pending" product record, used for new product entry workflow.
+    """
+    __tablename__ = 'pending_product'
+    __table_args__ = (
+        sa.ForeignKeyConstraint(['user_uuid'], ['user.uuid'], name='pending_product_fk_user'),
+        sa.ForeignKeyConstraint(['department_uuid'], ['department.uuid'], name='pending_product_fk_department'),
+        sa.ForeignKeyConstraint(['brand_uuid'], ['brand.uuid'], name='pending_product_fk_brand'),
+    )
+
+    uuid = uuid_column()
+
+    user_uuid = sa.Column(sa.String(length=32), nullable=False)
+    user = orm.relationship(
+        'User',
+        doc="""
+        Reference to the :class:`~rattail:rattail.db.model.User` who
+        first entered the record.
+        """)
+
+    created = sa.Column(sa.DateTime(), nullable=False,
+                        default=datetime.datetime.utcnow, doc="""
+    Timestamp when the record was first created.
+    """)
+
+    # Product fields
+    upc = sa.Column(GPCType(), nullable=True)
+    scancode = sa.Column(sa.String(length=14), nullable=True)
+    item_id = sa.Column(sa.String(length=50), nullable=True)
+    item_type = sa.Column(sa.Integer(), nullable=True)
+
+    department_name = sa.Column(sa.String(length=30), nullable=True)
+    department_uuid = sa.Column(sa.String(length=32), nullable=True)
+    department = orm.relationship(Department)
+
+    brand_name = sa.Column(sa.String(length=100), nullable=True)
+    brand_uuid = sa.Column(sa.String(length=32), nullable=True)
+    brand = orm.relationship(Brand)
+
+    description = sa.Column(sa.String(length=255), nullable=True)
+    size = sa.Column(sa.String(length=30), nullable=True)
+    case_size = sa.Column(sa.Numeric(precision=9, scale=4), nullable=True)
+    regular_price_amount = sa.Column(sa.Numeric(precision=8, scale=3), nullable=True)
+    special_order = sa.Column(sa.Boolean(), nullable=True)
+    notes = sa.Column(sa.Text(), nullable=True)
+
+    # workflow fields
+    status_code = sa.Column(sa.Integer(), nullable=True, doc="""
+    Status indicator for the new product record.
+    """)
+
+    @property
+    def full_description(self):
+        return make_full_description(self.brand_name,
+                                     self.description,
+                                     self.size)
+
+    def __str__(self):
+        if six.PY2:
+            return self.full_description.encode('utf8')
+        return self.full_description
+
+    if six.PY2:
+        def __unicode__(self):
+            return self.full_description
+
+
 @six.python_2_unicode_compatible
 class InventoryAdjustmentReason(Base):
     """
