@@ -340,7 +340,9 @@ class GlobalRoleImporter(RoleImporter):
         model = self.model
 
         # users
-        if 'users' in self.fields:
+        # nb. we only update users if this role has flag set
+        if 'users' in self.fields and role.sync_users:
+
             new_users = host_data['users']
             old_users = local_data['users'] if local_data else []
             changed = False
