@@ -340,6 +340,20 @@ class rattail_batch_purchase_allow_receiving_from_purchase_order(Setting):
     data_type = bool
 
 
+class rattail_batch_purchase_allow_receiving_from_purchase_order_with_invoice(Setting):
+    """
+    Determines whether or not receiving "from PO with invoice" is
+    allowed.  In this mode, the user must first select the purchase
+    order (PO) they wish to receive against, as well as upload an
+    invoice file.  The batch is initially populated with order
+    quantities from the PO, then the invoice data is overlaid onto it.
+    """
+    group = "Purchasing / Receiving"
+    namespace = 'rattail.batch'
+    name = 'purchase.allow_receiving_from_purchase_order_with_invoice'
+    data_type = bool
+
+
 class rattail_batch_purchase_allow_truck_dump_receiving(Setting):
     """
     Determines whether or not "truck dump" receiving is allowed.  This is a
